@@ -1,5 +1,4 @@
-from eventlet.green import zmq
-import time
+from gevent_zeromq import zmq
 import json
 from uuid import uuid4
 import cgi
@@ -34,6 +33,12 @@ class Request(object):
         self.headers = headers
         self.body = body
 
+        if self.headers['METHOD'] == 'JSON':
+            self.data = json.loads(body)
+        else:
+            self.data = {}
+
+
         # populate arguments with QUERY string
         self.arguments = {}
         if 'QUERY' in self.headers:
@@ -103,8 +108,8 @@ class Request(object):
 
     def is_disconnect(self):
         if self.headers.get('METHOD') == 'JSON':
-            logging.error('DISONNECT')
-            return self.headers.get('type') == 'disconnect'
+            logging.error('DISCONNECT')
+            return self.data.get('type') == 'disconnect'
 
     def should_close(self):
         """Determines if Request data matches criteria for closing request"""
